<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\127\157\162\x64\x50\162\145\x73\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\157\x64\145\152\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\x53\x74\141\x74\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\x50\x79\164\x68\x6f\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\x65\x76\x65\x72\x73\x65\x50\162\x6f\170\x79"; private const VARNISH_CACHE_SERVER = "\x31\x32\67\56\x30\x2e\60\56\61\x3a\x36\60\x38\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\x53\x5f\x4d\105\124\x48\x4f\104" => ["\166\x61\154\165\145" => "\x64\x69\162\x65\143\164", "\162\x61\167" => false], "\127\x50\x5f\x44\105\102\125\x47\x5f\x44\111\123\x50\x4c\101\131" => ["\x76\141\154\165\145" => "\146\x61\154\163\x65", "\162\x61\167" => true], "\x57\120\x5f\x44\x45\x42\x55\x47\137\x4c\x4f\107" => ["\x76\x61\154\165\145" => "\164\x72\165\x65", "\162\x61\167" => true], "\103\x4f\x4e\103\x41\x54\x45\116\101\x54\105\137\123\103\122\111\120\x54\x53" => ["\166\141\154\x75\145" => "\x66\x61\154\163\x65", "\x72\141\167" => true], "\x41\x55\124\x4f\123\101\126\105\x5f\x49\116\x54\x45\x52\x56\101\x4c" => ["\166\x61\x6c\x75\x65" => 600, "\162\x61\167" => true], "\127\120\137\x50\x4f\x53\124\x5f\122\x45\x56\x49\x53\111\117\x4e\x53" => ["\166\x61\154\165\x65" => 5, "\x72\141\x77" => true], "\x45\x4d\120\124\x59\137\124\122\101\x53\x48\137\104\x41\131\x53" => ["\x76\x61\x6c\x75\145" => 21, "\162\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\x57\120\137\101\x4c\x4c\117\x57\x5f\x4d\125\x4c\x54\x49\123\111\x54\x45" => ["\x76\141\154\x75\145" => "\x74\162\x75\x65", "\162\141\x77" => true], "\x4d\x55\114\x54\x49\123\x49\124\x45" => ["\166\141\154\x75\x65" => "\x74\x72\165\145", "\x72\x61\167" => true], "\x53\x55\102\x44\117\x4d\x41\x49\x4e\x5f\x49\x4e\x53\124\x41\x4c\x4c" => ["\166\x61\154\165\145" => "\x66\141\154\163\145", "\x72\141\167" => true], "\x44\117\x4d\x41\111\x4e\137\x43\125\x52\122\x45\116\124\x5f\123\x49\124\x45" => ["\166\141\x6c\x75\x65" => '', "\x72\141\x77" => false], "\x50\x41\x54\110\x5f\103\125\122\x52\x45\x4e\124\x5f\123\x49\x54\x45" => ["\x76\x61\154\165\x65" => "\x2f", "\x72\141\167" => false], "\123\x49\x54\105\x5f\x49\x44\137\x43\125\122\122\105\116\124\137\x53\111\x54\105" => ["\x76\x61\x6c\x75\145" => 1, "\x72\x61\x77" => true], "\x42\114\x4f\107\x5f\111\104\137\103\125\x52\122\105\x4e\124\x5f\x53\111\x54\105" => ["\x76\x61\154\x75\145" => 1, "\162\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto F8bb0; a2bf4: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto c9721; Dd8b0: $this->databaseServerEntityManager = $databaseServerEntityManager; goto a2bf4; ad395: $this->siteEntityManager = $siteEntityManager; goto F0ed7; F50a7: $this->databaseEntityManager = $databaseEntityManager; goto abfb7; abfb7: $this->databaseUserEntityManager = $databaseUserEntityManager; goto Dd8b0; e95f9: parent::__construct($translator, $logger); goto bd434; ca247: $this->validator = $validator; goto e95f9; F0ed7: $this->certificateEntityManager = $certificateEntityManager; goto F50a7; F8bb0: $this->configManager = $configManager; goto ad395; c9721: $this->domainNameParser = $domainNameParser; goto ca247; bd434: } public function index(Request $request) : Response { goto Bc6be; E6128: $response = $this->render("\x46\x72\x6f\156\x74\x65\156\144\x2f\x53\x69\164\145\x2f\116\145\167\x2f\151\156\144\145\170\x2e\150\164\x6d\154\56\164\x77\x69\x67", ["\165\x73\x65\162" => $user]); goto F551f; be82c: return $response; goto D7254; A8a27: $user = $this->getUser(); goto E6128; acd68: goto B90da; goto ea68f; F551f: B90da: goto be82c; a3108: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\x69\164\145\x73")); goto acd68; Bc6be: $hasPermissions = $this->hasPermissions(); goto Fab2f; ea68f: A560f: goto A8a27; Fab2f: if (true === $hasPermissions) { goto A560f; } goto a3108; D7254: } public function newPythonSite(Request $request) : Response { goto dffb6; e568d: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\164\145\x73")); goto C58ea; D785f: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto D8b0f; } goto Db937; C58ea: goto f608d; goto F4b9c; Cc5ad: D8b0f: goto a7872; Ff939: if (!(false === is_null($response))) { goto Bb720; } goto Cbe39; D82d4: if (!(true === $form->isSubmitted())) { goto f531c; } goto a6ee9; a72e3: f531c: goto Cc5ad; C82ac: Bb720: goto a72e3; f190e: $user = $this->getUser(); goto bb101; Cbe39: return $response; goto C82ac; deed7: if (true === $hasPermissions) { goto b45e9; } goto e568d; bb101: $pythonSettings = new PythonSettingsEntity(); goto a5922; F4b9c: b45e9: goto f190e; a6ee9: $response = $this->handleCreatePythonSiteForm($request, $form); goto Ff939; a470b: return $response; goto C00a8; dffb6: $hasPermissions = $this->hasPermissions(); goto deed7; a5922: $form = $this->createPythonSiteForm($pythonSettings); goto D785f; F7c95: f608d: goto a470b; Db937: $form->handleRequest($request); goto D82d4; a7872: $response = $this->render("\106\162\157\156\x74\x65\156\x64\57\123\x69\x74\145\x2f\116\145\x77\x2f\x70\x79\164\150\157\156\x2e\x68\x74\155\x6c\x2e\164\x77\x69\147", ["\x75\163\145\162" => $user, "\146\x6f\162\155" => $form->createView(), "\146\157\162\155\x45\162\x72\157\x72\x73" => $this->formErrors]); goto F7c95; C00a8: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto aa616; De082: $form->add("\x73\165\142\x6d\151\164", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\154\x61\x73\x73" => "\142\x74\x6e\x20\x62\x74\156\55\x6c\x67\x20\x62\x74\156\x2d\142\x6c\x75\145"], "\x6c\141\142\145\x6c" => "\103\x72\x65\x61\164\x65"]); goto b12fd; b12fd: return $form; goto c5185; aa616: $form = $this->createForm("\x41\x70\160\134\x46\157\162\155\x5c\x53\x69\164\145\116\x65\167\x50\171\164\x68\x6f\156\x54\171\160\145", $pythonSettings, ["\x61\143\164\x69\x6f\x6e" => $this->generateUrl("\143\154\x70\137\x73\151\x74\145\x5f\x70\171\164\x68\x6f\156\x5f\156\145\167"), "\155\145\x74\150\x6f\144" => "\120\x4f\x53\124", "\x61\164\x74\162" => ["\151\x64" => "\x6e\145\x77\55\160\171\164\x68\x6f\156\55\163\x69\164\x65\x2d\x66\x6f\162\155"]]); goto De082; c5185: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto f37b6; f37b6: if (true === $form->isValid()) { goto Aa6ca; } goto e9a83; Af877: goto f2c49; goto c9f41; e9a83: $this->formErrors = $this->getErrorMessages($form); goto Af877; c9f41: Aa6ca: goto dd58c; a2ee8: f2c49: goto b4bb6; dd58c: try { goto bf2a7; ccf28: $siteUser = $form->get("\x73\x69\x74\145\x55\x73\x65\162")->getData(); goto F4910; Ce59a: return $response; goto f9b13; Faf8d: $user = $this->getUser(); goto D6a60; cfd82: $domainName = $form->get("\x64\157\x6d\141\x69\x6e\x4e\141\x6d\x65")->getData(); goto Ef762; Ef762: $pythonVersion = $form->get("\160\171\x74\x68\157\156\x56\x65\x72\163\x69\x6f\x6e")->getData(); goto D01f1; F7c69: b0947: goto Faf8d; bf2a7: $session = $request->getSession(); goto cfd82; f9b13: d1558: goto b480b; be489: goto d1558; goto F7c69; Abab9: $eventData = ["\163\x69\164\145" => $domainName, "\163\x69\164\x65\x55\x73\145\x72" => $siteUser, "\160\171\x74\x68\x6f\x6e\x56\145\x72\x73\151\x6f\x6e" => $pythonVersion, "\x70\x6f\x72\164" => $port]; goto Eea28; D01f1: $port = $form->get("\160\x6f\x72\164")->getData(); goto ccf28; D6a60: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto Abab9; ad4c6: $response = $this->redirect($this->generateUrl("\143\154\160\137\163\151\164\x65\x73")); goto Ce59a; a139b: if (false === is_null($vhostTemplateEntity)) { goto b0947; } goto e1747; aa0d8: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto a139b; F4910: $siteUserPassword = $form->get("\x73\151\x74\145\125\163\x65\162\120\x61\163\x73\x77\157\162\x64")->getData(); goto af72e; e1747: throw new \Exception(sprintf("\126\150\157\x73\164\40\x74\x65\155\160\x6c\x61\164\x65\40\42\x25\163\42\40\156\157\x74\x20\146\x6f\x75\156\x64\56", $vhostTemplateName)); goto be489; Eea28: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto D1859; af72e: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto aa0d8; D1859: $session->getFlashBag()->set("\163\165\143\x63\145\163\x73", $this->translator->trans("\123\x69\164\145\40\150\141\163\x20\142\145\145\156\x20\143\x72\145\141\164\145\144\x2e")); goto ad4c6; b480b: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\145\x72", $this->translator->trans("\x41\x6e\x20\x65\162\162\157\x72\40\150\x61\x73\x20\x6f\x63\x63\x75\x72\x72\145\144\54\40\145\162\162\157\162\40\155\x65\x73\x73\x61\x67\145\72\x20\45\145\x72\162\157\162\x4d\145\163\163\x61\x67\x65\x25", ["\45\145\x72\x72\x6f\162\115\145\x73\163\x61\x67\145\45" => $e->getMessage()])); } goto a2ee8; b4bb6: } public function newReverseProxy(Request $request) : Response { goto A79ac; B91ae: return $response; goto cff98; d89f0: return $response; goto Ab780; cfca2: $user = $this->getUser(); goto c657a; db4e4: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\151\164\x65\x73")); goto F64e7; e953a: if (!(true === $form->isSubmitted())) { goto fbfb4; } goto c12b8; cff98: ca10b: goto C4e6e; A79ac: $hasPermissions = $this->hasPermissions(); goto Ad2cf; A268d: f6ddb: goto cfca2; baff1: $response = $this->render("\x46\x72\x6f\x6e\x74\x65\x6e\144\x2f\x53\151\164\x65\57\116\x65\x77\57\162\145\166\x65\162\163\x65\55\x70\x72\157\170\x79\56\150\x74\155\x6c\x2e\164\167\x69\x67", ["\165\163\145\x72" => $user, "\146\x6f\x72\155" => $form->createView(), "\146\157\x72\x6d\105\x72\162\x6f\x72\163" => $this->formErrors]); goto C609e; c657a: $form = $this->createReverseProxyForm(); goto Bc55c; Ad2cf: if (true === $hasPermissions) { goto f6ddb; } goto db4e4; c12b8: $response = $this->handleReverseProxyForm($request, $form); goto c3e97; C4e6e: fbfb4: goto e835a; Bc55c: if (!(true === $request->isMethod("\120\117\x53\124"))) { goto Ceabe; } goto f8417; C609e: C3210: goto d89f0; F64e7: goto C3210; goto A268d; e835a: Ceabe: goto baff1; c3e97: if (!(false === is_null($response))) { goto ca10b; } goto B91ae; f8417: $form->handleRequest($request); goto e953a; Ab780: } private function createReverseProxyForm() : Form { goto ec1c8; ec1c8: $form = $this->createForm("\101\160\160\134\x46\157\162\x6d\x5c\123\x69\164\x65\x4e\x65\167\122\x65\x76\145\x72\x73\145\120\x72\x6f\x78\171\x54\x79\160\x65", [], ["\141\x63\x74\151\x6f\x6e" => $this->generateUrl("\x63\x6c\x70\137\x73\151\x74\x65\x5f\x72\145\x76\145\162\x73\145\x5f\160\x72\x6f\170\x79\x5f\x6e\x65\167"), "\x6d\x65\x74\x68\x6f\144" => "\120\x4f\123\x54", "\141\x74\x74\x72" => ["\151\144" => "\156\145\x77\55\x72\x65\166\x65\x72\163\x65\55\160\162\157\170\x79\x2d\146\x6f\x72\155"]]); goto e9fb3; e9fb3: $form->add("\163\165\142\155\x69\164", SubmitType::class, ["\141\x74\x74\162" => ["\143\x6c\x61\163\x73" => "\x62\164\156\40\x62\164\x6e\x2d\x6c\x67\x20\142\x74\x6e\x2d\142\x6c\165\145"], "\x6c\x61\142\145\x6c" => "\103\162\145\x61\x74\145"]); goto aa7bc; aa7bc: return $form; goto Dd78b; Dd78b: } private function handleReverseProxyForm(Request $request, Form $form) { goto Cd7ea; A96c5: c45af: goto B554e; a59c9: $this->formErrors = $this->getErrorMessages($form); goto Fa13d; Fa13d: goto c45af; goto A1403; A1403: c8259: goto Baa91; Cd7ea: if (true === $form->isValid()) { goto c8259; } goto a59c9; Baa91: try { goto cd07b; Dec42: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto c026c; Cab40: $user = $this->getUser(); goto Dec42; c026c: $eventData = ["\x73\151\x74\x65" => $domainName, "\x73\x69\x74\x65\125\x73\145\162" => $siteUser, "\x72\x65\x76\145\x72\163\x65\x50\162\x6f\x78\x79\x55\162\x6c" => $reverseProxyUrl]; goto a541e; C3d42: b2579: goto Cab40; D8590: e20f8: goto D2f9c; D20c7: $siteUserPassword = $form->get("\163\x69\164\x65\125\163\x65\x72\120\x61\x73\x73\167\x6f\x72\x64")->getData(); goto B7acc; B7acc: $reverseProxyUrl = $form->get("\x72\x65\166\x65\x72\x73\x65\120\x72\157\170\x79\125\162\x6c")->getData(); goto A0fe7; b33cf: $session->getFlashBag()->set("\x73\165\143\143\145\x73\x73", $this->translator->trans("\x52\x65\166\145\162\x73\x65\40\x50\162\x6f\x78\x79\x20\x68\x61\x73\40\142\x65\145\x6e\x20\143\x72\x65\x61\x74\145\x64\x2e")); goto C23e9; Ee9b5: goto e20f8; goto C3d42; C31fe: $siteUser = $form->get("\x73\151\164\145\x55\163\145\162")->getData(); goto D20c7; d63f3: return $response; goto D8590; C23e9: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\x69\164\145\x73")); goto d63f3; d5c6b: $domainName = $form->get("\144\157\155\x61\x69\x6e\116\x61\x6d\145")->getData(); goto C31fe; A0fe7: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto D9471; D9471: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ce151; cd07b: $session = $request->getSession(); goto d5c6b; a541e: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto b33cf; Ce151: if (false === is_null($vhostTemplateEntity)) { goto b2579; } goto Ef9d5; Ef9d5: throw new \Exception(sprintf("\x56\150\x6f\x73\164\40\x74\x65\155\x70\x6c\141\164\145\x20\x22\45\x73\x22\40\156\x6f\164\x20\x66\x6f\165\156\x64\56", $vhostTemplateName)); goto Ee9b5; D2f9c: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\145\162", $this->translator->trans("\101\156\40\x65\162\162\157\162\x20\150\141\x73\x20\157\x63\143\x75\162\162\x65\x64\54\x20\145\162\162\x6f\162\40\155\145\x73\x73\141\147\145\x3a\x20\x25\x65\x72\x72\157\162\115\145\x73\x73\141\147\x65\x25", ["\45\145\x72\162\x6f\162\115\x65\x73\x73\141\x67\x65\45" => $e->getMessage()])); } goto A96c5; B554e: } public function newNodejsSite(Request $request) : Response { goto ea592; ba4f6: $form = $this->createNodejsSiteForm($nodejsSettings); goto ba513; ea592: $hasPermissions = $this->hasPermissions(); goto fe5e9; b904d: F74ea: goto a00d6; D42df: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\151\x74\145\x73")); goto a57aa; e03ca: $form->handleRequest($request); goto Bab86; a57aa: goto e761f; goto ad4d8; Bab86: if (!(true === $form->isSubmitted())) { goto D628d; } goto af549; F97e0: D628d: goto b904d; ef35a: e761f: goto E44c1; fe5e9: if (true === $hasPermissions) { goto B49c6; } goto D42df; a00d6: $response = $this->render("\x46\162\x6f\x6e\164\x65\156\144\x2f\123\x69\x74\145\x2f\x4e\x65\167\x2f\156\157\x64\x65\152\163\x2e\x68\164\x6d\154\56\164\167\x69\x67", ["\165\x73\145\162" => $user, "\146\x6f\162\155" => $form->createView(), "\146\x6f\x72\x6d\x45\162\162\157\x72\163" => $this->formErrors]); goto ef35a; d3ad7: return $response; goto Fdb55; Abdae: $user = $this->getUser(); goto b9993; b9993: $nodejsSettings = new NodejsSettingsEntity(); goto ba4f6; Fdb55: b5645: goto F97e0; ad4d8: B49c6: goto Abdae; E44c1: return $response; goto b124b; af549: $response = $this->handleCreateNodejsSiteForm($request, $form); goto E0bc4; ba513: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto F74ea; } goto e03ca; E0bc4: if (!(false === is_null($response))) { goto b5645; } goto d3ad7; b124b: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto C385a; Cf0a2: $form->add("\163\165\x62\x6d\x69\164", SubmitType::class, ["\141\164\164\x72" => ["\x63\x6c\141\x73\163" => "\142\x74\x6e\40\x62\x74\156\x2d\x6c\x67\x20\x62\x74\156\55\x62\154\x75\x65"], "\x6c\x61\142\x65\154" => "\103\x72\x65\141\x74\145"]); goto D37e9; D37e9: return $form; goto Ca330; C385a: $form = $this->createForm("\101\160\160\x5c\x46\157\x72\x6d\134\123\151\164\x65\x4e\x65\x77\116\x6f\144\x65\x6a\163\x54\171\160\145", $nodejsSettings, ["\x61\x63\164\x69\x6f\x6e" => $this->generateUrl("\143\154\x70\x5f\163\151\x74\145\x5f\156\157\144\145\x6a\x73\x5f\x6e\x65\167"), "\x6d\x65\x74\x68\157\144" => "\120\x4f\x53\124", "\x61\164\164\x72" => ["\151\144" => "\x6e\145\167\x2d\156\157\x64\145\152\163\x2d\x73\x69\x74\145\55\146\x6f\x72\155"]]); goto Cf0a2; Ca330: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto ce524; b24dc: C5b41: goto e9dc7; ce524: if (true === $form->isValid()) { goto A058b; } goto C06d1; c001e: A058b: goto Ab4e2; Ab4e2: try { goto D90d7; e6b90: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ef357; f3f47: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto Edb5b; d21c0: $siteUser = $form->get("\x73\151\164\145\x55\x73\x65\x72")->getData(); goto D76d7; De7b5: C52d3: goto e3849; c1e41: $eventData = ["\x73\151\164\145" => $domainName, "\x73\151\x74\x65\125\163\145\162" => $siteUser, "\x6e\157\x64\x65\x6a\x73\126\x65\x72\163\151\157\156" => $nodejsVersion, "\160\157\x72\164" => $port]; goto f3f47; D90d7: $session = $request->getSession(); goto e4775; C1e78: $user = $this->getUser(); goto F0db0; bcf45: goto C52d3; goto Addbc; D76d7: $siteUserPassword = $form->get("\x73\x69\164\145\x55\163\145\x72\x50\x61\x73\163\x77\x6f\162\x64")->getData(); goto D20af; Addbc: Bb918: goto C1e78; d6da2: return $response; goto De7b5; F1da7: throw new \Exception(sprintf("\126\x68\157\x73\x74\x20\164\145\x6d\x70\154\x61\x74\x65\x20\x22\45\163\42\40\x6e\157\x74\x20\x66\157\x75\156\144\x2e", $vhostTemplateName)); goto bcf45; Bf1bf: $nodejsVersion = $form->get("\156\x6f\x64\x65\x6a\x73\126\145\x72\163\x69\157\156")->getData(); goto a2ad5; a2ad5: $port = $form->get("\160\x6f\x72\164")->getData(); goto d21c0; Ef357: if (false === is_null($vhostTemplateEntity)) { goto Bb918; } goto F1da7; B968f: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\151\164\x65\163")); goto d6da2; D20af: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto e6b90; F0db0: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto c1e41; e4775: $domainName = $form->get("\x64\x6f\x6d\141\x69\156\116\x61\x6d\x65")->getData(); goto Bf1bf; Edb5b: $session->getFlashBag()->set("\163\165\143\143\x65\163\163", $this->translator->trans("\123\151\x74\x65\40\150\141\163\40\142\x65\145\x6e\x20\x63\162\145\x61\x74\x65\144\x2e")); goto B968f; e3849: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\x67\x65\x72", $this->translator->trans("\x41\x6e\x20\x65\x72\162\x6f\x72\x20\150\x61\x73\40\x6f\x63\x63\x75\162\162\145\x64\x2c\40\x65\162\162\157\x72\x20\155\x65\x73\x73\x61\147\x65\72\40\x25\145\x72\162\157\x72\x4d\145\x73\163\x61\147\145\x25", ["\x25\x65\x72\x72\x6f\x72\x4d\145\x73\x73\x61\147\x65\45" => $e->getMessage()])); } goto b24dc; Ce023: goto C5b41; goto c001e; C06d1: $this->formErrors = $this->getErrorMessages($form); goto Ce023; e9dc7: } public function newStaticSite(Request $request) : Response { goto Bbf3f; f6f93: b8262: goto c080a; f1ae7: D7661: goto b51bc; E9334: goto b8262; goto f1ae7; fd2c0: $form->handleRequest($request); goto C42f3; c080a: return $response; goto D4af7; C7d0c: if (!(false === is_null($response))) { goto f1d4b; } goto Aba02; Bfd20: bd847: goto Ce9a9; C3d5a: $form = $this->createStaticSiteForm(); goto ed295; fd9f2: f1d4b: goto D1af1; b51bc: $user = $this->getUser(); goto C3d5a; d8f8b: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\164\145\x73")); goto E9334; C42f3: if (!(true === $form->isSubmitted())) { goto Ab491; } goto Eae17; D1af1: Ab491: goto Bfd20; e2b32: if (true === $hasPermissions) { goto D7661; } goto d8f8b; Eae17: $response = $this->handleCreateStaticSiteForm($request, $form); goto C7d0c; Aba02: return $response; goto fd9f2; Ce9a9: $response = $this->render("\x46\162\x6f\x6e\x74\x65\156\x64\x2f\123\x69\164\x65\x2f\x4e\x65\167\x2f\163\164\x61\164\x69\143\x2e\150\x74\x6d\154\56\x74\167\x69\x67", ["\x75\x73\145\x72" => $user, "\x66\x6f\162\x6d" => $form->createView(), "\x66\157\x72\155\x45\162\x72\157\x72\163" => $this->formErrors]); goto f6f93; Bbf3f: $hasPermissions = $this->hasPermissions(); goto e2b32; ed295: if (!(true === $request->isMethod("\120\x4f\x53\x54"))) { goto bd847; } goto fd2c0; D4af7: } private function createStaticSiteForm() : Form { goto e7d9a; Ff6be: $form->add("\163\165\x62\155\x69\x74", SubmitType::class, ["\x61\x74\164\162" => ["\143\154\141\163\x73" => "\x62\164\x6e\x20\142\164\156\55\154\147\40\x62\x74\x6e\55\x62\x6c\x75\x65"], "\154\141\x62\145\x6c" => "\103\162\x65\141\x74\145"]); goto dfbee; dfbee: return $form; goto d0157; e7d9a: $form = $this->createForm("\101\160\160\134\x46\157\162\155\x5c\x53\151\164\x65\x4e\145\167\123\x74\141\164\151\143\124\171\160\x65", [], ["\141\143\164\151\x6f\x6e" => $this->generateUrl("\x63\x6c\x70\137\163\x69\164\145\137\163\x74\141\164\x69\143\137\156\x65\x77"), "\155\145\x74\150\x6f\x64" => "\120\x4f\123\x54", "\141\164\x74\x72" => []]); goto Ff6be; d0157: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto ec592; f5509: B25e2: goto C47a5; D2a41: goto D76eb; goto f5509; C47a5: try { goto E8bc9; B6dc7: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto c35d8; c35d8: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto eb67b; B00db: $siteUser = $form->get("\163\x69\x74\x65\x55\x73\145\162")->getData(); goto A6f74; eb67b: if (false === is_null($vhostTemplateEntity)) { goto dd262; } goto b64f8; dc7cb: $domainName = $form->get("\144\157\155\x61\x69\x6e\116\141\155\x65")->getData(); goto B00db; dee00: $user = $this->getUser(); goto a59a7; A6f74: $siteUserPassword = $form->get("\163\151\x74\x65\125\163\145\x72\120\141\163\163\167\x6f\162\144")->getData(); goto B6dc7; Eda00: return $response; goto f292a; f292a: a1de6: goto c0cd2; E8bc9: $session = $request->getSession(); goto dc7cb; Fea5e: dd262: goto dee00; a59a7: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto a06d8; a06d8: $eventData = ["\x73\151\x74\x65" => $domainName, "\163\151\x74\145\125\163\145\x72" => $siteUser]; goto fe319; Fc14a: $session->getFlashBag()->set("\x73\165\143\143\145\x73\x73", $this->translator->trans("\123\151\x74\145\40\x68\x61\163\40\x62\145\x65\x6e\40\143\162\x65\x61\164\x65\144\56")); goto Cc8ce; F2662: goto a1de6; goto Fea5e; Cc8ce: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\163\151\x74\x65\163")); goto Eda00; fe319: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Fc14a; b64f8: throw new \Exception(sprintf("\x56\x68\x6f\x73\164\x20\x74\x65\x6d\x70\x6c\141\x74\145\40\42\x25\x73\x22\40\x6e\x6f\164\40\x66\x6f\x75\x6e\144\56", $vhostTemplateName)); goto F2662; c0cd2: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\x65\x72", $this->translator->trans("\x41\156\x20\145\x72\162\x6f\x72\40\x68\141\163\x20\x6f\143\x63\x75\162\x72\145\x64\x2c\40\145\x72\162\x6f\x72\x20\x6d\x65\x73\x73\x61\x67\145\72\40\45\x65\x72\x72\157\162\x4d\145\x73\x73\141\x67\x65\45", ["\45\145\x72\162\x6f\162\115\x65\163\163\141\x67\x65\x25" => $e->getMessage()])); } goto C76cf; Cae3c: $this->formErrors = $this->getErrorMessages($form); goto D2a41; ec592: if (true === $form->isValid()) { goto B25e2; } goto Cae3c; C76cf: D76eb: goto d0ce9; d0ce9: } public function newPhpSite(Request $request) : Response { goto f76f8; Ec433: $form = $this->createPhpSiteForm(); goto e45b5; D942c: C82f2: goto B4f77; d92e7: $form->handleRequest($request); goto Ca439; Be712: if (!(false === is_null($response))) { goto Ffcec; } goto B2ecc; c7ff0: $response = $this->handleCreatePhpSiteForm($request, $form); goto Be712; d505c: Ffcec: goto Ff9e0; a8873: if (true === $hasPermissions) { goto aa9b1; } goto Ff8dd; B4f77: $response = $this->render("\106\x72\x6f\x6e\164\145\156\x64\57\x53\x69\164\145\57\116\145\x77\57\160\150\160\56\150\x74\x6d\154\x2e\164\167\151\147", ["\x75\163\145\162" => $user, "\146\157\162\x6d" => $form->createView(), "\x66\x6f\162\155\x45\x72\x72\x6f\162\163" => $this->formErrors]); goto Be446; Ff9e0: Ab6b0: goto D942c; b7d65: goto a3448; goto a951d; cd09f: return $response; goto ae4ca; f76f8: $hasPermissions = $this->hasPermissions(); goto a8873; Ff8dd: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\151\164\145\163")); goto b7d65; F153e: $user = $this->getUser(); goto Ec433; B2ecc: return $response; goto d505c; Be446: a3448: goto cd09f; a951d: aa9b1: goto F153e; Ca439: if (!(true === $form->isSubmitted())) { goto Ab6b0; } goto c7ff0; e45b5: if (!(true === $request->isMethod("\120\x4f\x53\124"))) { goto C82f2; } goto d92e7; ae4ca: } private function createPhpSiteForm() : Form { goto e0c23; e0c23: $form = $this->createForm("\101\160\x70\x5c\x46\x6f\162\x6d\134\123\x69\164\145\116\145\167\x50\x68\x70\x54\x79\160\x65", [], ["\x61\x63\164\x69\x6f\x6e" => $this->generateUrl("\143\x6c\x70\137\x73\x69\164\x65\137\x70\x68\160\x5f\x6e\x65\167"), "\155\145\164\150\x6f\x64" => "\120\117\123\124", "\141\x74\x74\162" => []]); goto Cd1b2; Fa364: return $form; goto e483a; Cd1b2: $form->add("\163\x75\142\155\x69\164", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\154\141\x73\x73" => "\142\x74\x6e\x20\x62\x74\156\55\154\x67\40\142\x74\x6e\x2d\142\154\x75\145"], "\154\141\142\145\154" => "\103\x72\x65\141\x74\145"]); goto Fa364; e483a: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto c8675; f2129: c1745: goto E8b78; Ab239: D2d27: goto F1d0b; Bdd8e: $this->formErrors = $this->getErrorMessages($form); goto B132e; c8675: if (true === $form->isValid()) { goto D2d27; } goto Bdd8e; F1d0b: try { goto db312; db312: $session = $request->getSession(); goto fb91b; f3c74: $siteUserPassword = $form->get("\163\151\164\145\125\x73\145\162\x50\x61\x73\x73\x77\157\162\144")->getData(); goto B8e09; E2356: $domainName = $form->get("\x64\x6f\155\141\151\x6e\116\141\155\x65")->getData(); goto B6c9c; B8e09: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B315e; bc44a: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto Cc56b; } goto D4cff; b268e: return $response; goto C7010; C7010: B6333: goto d560e; dbc2d: aa897: goto A4cea; c419b: throw new \Exception(sprintf("\x56\x68\x6f\163\164\x20\164\x65\x6d\160\x6c\141\164\x65\x20\42\x25\163\42\40\156\x6f\x74\40\146\x6f\165\156\144\56", $vhostTemplateName)); goto a6995; B6c9c: $phpVersion = $form->get("\x70\150\160\126\145\x72\x73\x69\157\x6e")->getData(); goto ff757; d69d6: a241a: goto Ac95a; Ac95a: $user = $this->getUser(); goto Bef35; ff757: $siteUser = $form->get("\x73\x69\x74\145\x55\163\145\x72")->getData(); goto f3c74; D4cff: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto b2a1d; c640b: $eventData = ["\x73\151\164\x65" => $domainName, "\166\150\x6f\x73\x74\x54\145\x6d\160\x6c\141\x74\145\x4e\141\x6d\145" => $vhostTemplateName, "\x70\x68\160\126\x65\x72\163\x69\x6f\156" => $phpVersion, "\x73\x69\x74\145\x55\163\x65\x72" => $siteUser]; goto E8a4e; Bef35: $rootDirectory = $domainName; goto Bd56c; fb91b: $vhostTemplateName = $form->get("\x61\x70\160\154\x69\143\x61\164\151\x6f\156")->getData(); goto E2356; B315e: if (false === is_null($vhostTemplateEntity)) { goto a241a; } goto c419b; bb85d: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\x69\x74\x65\163")); goto b268e; a6995: goto B6333; goto d69d6; A4cea: $varnishCacheSettings = []; goto bc44a; ff964: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto c640b; Bd56c: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto aa897; } goto Bd7be; Bd7be: $rootDirectory = sprintf("\x25\163\57\45\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\57"), "\x2f")); goto dbc2d; d9608: $session->getFlashBag()->set("\163\x75\x63\x63\145\x73\163", $this->translator->trans("\123\151\x74\x65\40\x68\x61\x73\40\142\x65\x65\156\40\143\x72\145\141\x74\x65\x64\56")); goto bb85d; b2a1d: Cc56b: goto ff964; E8a4e: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto d9608; d560e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\145\162", $this->translator->trans("\x41\x6e\40\145\162\x72\157\x72\40\150\x61\x73\40\157\143\x63\165\x72\x72\145\144\54\x20\x65\162\162\157\x72\40\x6d\x65\163\x73\x61\x67\145\72\x20\45\x65\162\x72\x6f\162\x4d\x65\163\x73\x61\x67\145\x25", ["\45\145\x72\162\157\x72\115\x65\163\163\141\x67\145\x25" => $e->getMessage()])); } goto f2129; B132e: goto c1745; goto Ab239; E8b78: } public function newWordPressSite(Request $request) : Response { goto F5dfc; F1a20: Ee06b: goto a2986; Cf2f3: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto A12db; } goto de018; e72a7: if (true === $hasPermissions) { goto f8ad9; } goto B0520; cbc1f: if (!(false === is_null($response))) { goto E765a; } goto F2cea; b8e1c: $response = $this->render("\x46\162\157\x6e\164\x65\156\144\x2f\123\151\x74\x65\57\x4e\145\x77\57\x77\x6f\x72\x64\160\162\x65\x73\163\x2e\150\164\155\154\x2e\164\167\x69\147", ["\x75\x73\x65\162" => $user, "\x66\x6f\x72\155" => $form->createView(), "\146\157\162\155\x45\162\162\157\162\x73" => $this->formErrors]); goto F1a20; a2986: return $response; goto d2866; dfc8d: f8ad9: goto E2c4c; de018: $form->handleRequest($request); goto Ec199; f3cc3: b69e6: goto B063e; B063e: A12db: goto b8e1c; B8ffb: $response = $this->handleCreateWordPressSiteForm($request, $form); goto cbc1f; F5dfc: $hasPermissions = $this->hasPermissions(); goto e72a7; a9a77: goto Ee06b; goto dfc8d; E2c4c: $user = $this->getUser(); goto a2657; F2cea: return $response; goto F5215; a2657: $form = $this->createWordPressSiteForm(); goto Cf2f3; B0520: $response = $this->redirect($this->generateUrl("\x63\154\160\137\x73\x69\164\145\163")); goto a9a77; Ec199: if (!(true === $form->isSubmitted())) { goto b69e6; } goto B8ffb; F5215: E765a: goto f3cc3; d2866: } private function createWordPressSiteForm() : Form { goto De60e; Bb40f: return $form; goto F45e5; F1ece: $form->add("\x73\165\142\x6d\151\164", SubmitType::class, ["\x61\x74\164\162" => ["\x63\154\x61\x73\163" => "\142\x74\156\x20\x62\x74\156\x2d\154\147\40\x62\x74\x6e\55\x62\x6c\x75\x65"], "\x6c\141\x62\x65\154" => "\103\162\145\141\164\x65"]); goto Bb40f; De60e: $form = $this->createForm("\x41\160\160\134\x46\157\162\155\x5c\x53\x69\164\x65\116\145\167\127\x6f\162\x64\x50\162\x65\x73\x73\x54\x79\160\145", [], ["\x61\x63\x74\x69\x6f\x6e" => $this->generateUrl("\x63\154\x70\137\x73\151\164\145\137\167\x6f\162\144\x70\162\145\163\x73\x5f\x6e\x65\x77"), "\x6d\145\164\150\157\x64" => "\x50\117\123\x54", "\141\164\x74\162" => ["\151\144" => "\156\145\x77\x2d\x77\157\162\x64\x70\162\x65\163\163\x2d\x73\x69\164\145\55\146\157\162\155"]]); goto F1ece; F45e5: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto ee8a7; e66ec: Aee14: goto Cca03; ee8a7: if (true === $form->isValid()) { goto A3a7e; } goto d72a5; C7012: try { goto de3b7; Cf4a2: $databaseEntity->addUser($databaseUserEntity); goto Bc67c; e1abf: $siteUser = $form->get("\x73\x69\x74\145\125\x73\145\162")->getData(); goto a4044; dea7f: $url = sprintf("\150\164\164\x70\x73\x3a\57\x2f\x25\163", $siteEntity->getDomainName()); goto C386d; d1a23: $databaseEntity->setName($databaseName); goto d305b; Cf846: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto c24be; ecd2f: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto ae190; E0570: $siteCredentials = [$this->translator->trans("\x53\151\x74\x65") => [$this->translator->trans("\111\x50\x20\101\144\x64\x72\145\x73\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\x6f\x6d\x61\x69\156\x20\x4e\x61\155\x65") => sprintf("\x68\164\x74\x70\x73\72\x2f\x2f\45\x73", $domainName), $this->translator->trans("\x53\x69\164\x65\40\125\163\x65\x72") => $siteUser, $this->translator->trans("\120\141\163\163\x77\157\162\x64") => $siteUserPassword]]; goto d9d5c; Fde21: $this->siteEntityManager->updateEntity($siteEntity); goto ecd2f; D93ce: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto b5afb; a2a15: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto f89e8; C332e: $siteCredentials["\127\157\162\x64\120\x72\x65\163\x73"] = [$this->translator->trans("\x41\144\x6d\151\156\40\105\x2d\115\141\151\x6c") => $adminEmail, $this->translator->trans("\x41\144\155\x69\x6e\x20\125\163\x65\x72\x20\x4e\141\x6d\145") => $adminUserName, $this->translator->trans("\x41\144\x6d\151\156\40\x50\x61\x73\x73\167\157\x72\144") => $adminPassword, $this->translator->trans("\101\x64\x6d\x69\x6e\x20\125\162\154") => sprintf("\x68\x74\x74\x70\x73\x3a\57\x2f\45\163\x2f\167\x70\55\141\x64\x6d\x69\156\x2f", rtrim($domainName, "\x2f"))]; goto aa621; Db718: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\151\164\x65\x5f\167\157\x72\x64\x70\x72\145\x73\x73\x5f\151\x6e\x73\164\141\154\154\x65\x64")); goto Bc370; f3c30: $instance = $request->attributes->get("\x69\156\x73\164\141\156\x63\x65"); goto E0570; Bc370: return $response; goto D47c8; Cce70: $databaseManager->createDatabase($databaseEntity); goto A7de6; a7aec: $adminPassword = $form->get("\x61\144\155\x69\156\x50\141\163\163\167\157\x72\x64")->getData(); goto e0022; D56ac: $isMultiSite = $form->get("\155\x75\154\x74\x69\x53\151\164\x65")->getData(); goto f83d8; B8a20: $adminUserName = $form->get("\141\144\155\x69\x6e\x55\x73\145\x72\x4e\141\155\x65")->getData(); goto a7aec; D4673: $session->set("\163\151\164\x65\x43\162\x65\x64\x65\156\164\x69\141\x6c\163", $siteCredentials); goto E693a; ba25c: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto Db718; b59f1: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto D93ce; A7de6: $databaseManager->createUser($databaseUserEntity); goto Fde21; f4395: $session = $request->getSession(); goto bf636; Ca925: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto d1a23; Bc67c: $siteEntity->addDatabase($databaseEntity); goto F6309; bd8ee: Ebb53: goto Cf846; ae190: $siteCredentials[$this->translator->trans("\104\141\x74\141\142\x61\163\145")] = [$this->translator->trans("\x48\x6f\x73\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\x6f\x72\164") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\x74\141\142\x61\x73\145\x20\x4e\x61\x6d\145") => $databaseName, $this->translator->trans("\104\x61\x74\141\142\141\x73\x65\x20\125\x73\x65\x72\x20\x4e\141\x6d\x65") => $databaseUserName, $this->translator->trans("\104\141\x74\x61\142\141\x73\145\x20\x55\163\x65\162\x20\120\x61\163\163\167\157\x72\x64") => $databaseUserPassword]; goto C332e; E693a: $eventData = ["\163\x69\x74\x65" => $domainName, "\163\151\164\145\x55\163\145\162" => $siteUser]; goto ba25c; f89e8: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto F73f9; C386d: $title = $form->get("\163\x69\164\x65\x54\151\164\x6c\x65")->getData(); goto B8a20; Fb87d: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto dea7f; c24be: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f3c30; C6396: $databaseEntity = $this->databaseEntityManager->createEntity(); goto Ca925; d8e77: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto bd8ee; f83d8: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto C6396; C2b09: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto D145b; bf636: $domainName = $form->get("\144\157\155\141\x69\x6e\x4e\x61\x6d\145")->getData(); goto B599b; a4044: $siteUserPassword = $form->get("\x73\x69\164\145\x55\163\x65\x72\x50\x61\x73\x73\167\157\x72\144")->getData(); goto b59f1; fe4b1: $databaseName = $this->getUniqueDatabaseName($generatedName); goto Dd267; d305b: $databaseEntity->setSite($siteEntity); goto C2b09; E924d: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto Ebb53; } goto d8e77; F73f9: $databaseUserEntity->setDatabase($databaseEntity); goto Cf4a2; b5afb: $varnishCacheSettings = []; goto E924d; B599b: $generatedName = $this->generateNameFromDomainName($domainName); goto e1abf; D145b: $databaseUserEntity->setUserName($databaseUserName); goto a2a15; d9d5c: if (!(false === is_null($siteEntity))) { goto C940c; } goto fe4b1; aa621: C940c: goto D4673; Dd267: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto Fb87d; e0022: $adminEmail = $form->get("\x61\144\x6d\151\x6e\105\155\x61\x69\x6c")->getData(); goto D56ac; F6309: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto Cce70; de3b7: $user = $this->getUser(); goto f4395; D47c8: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\147\145\x72", $this->translator->trans("\x41\156\x20\145\162\x72\157\x72\40\150\141\x73\40\x6f\143\x63\165\162\162\x65\x64\x2c\x20\x65\x72\x72\x6f\162\x20\155\x65\x73\x73\x61\x67\145\x3a\40\45\145\162\x72\x6f\162\x4d\x65\163\163\141\147\x65\45", ["\45\145\162\162\x6f\162\115\x65\163\x73\x61\x67\x65\45" => $e->getMessage()])); } goto e66ec; d72a5: $this->formErrors = $this->getErrorMessages($form); goto C1be1; c89f1: A3a7e: goto C7012; C1be1: goto Aee14; goto c89f1; Cca03: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto c8b85; C08fa: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto E4508; E36d0: e3d4e: goto A3cc8; E4508: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\154\x75\x65"], $config["\162\141\167"]); Ecb1a: } goto e9f84; d3f78: E0610: goto E36d0; E2684: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\x6c\165\x65"], $config["\x72\x61\167"]); f714b: } goto d3f78; Cc733: $databaseName = $databaseEntity->getName(); goto Cee2b; B4093: if (!(true === $isMultiSite)) { goto e3d4e; } goto C86ad; e9f84: a2c0e: goto B4093; A3cc8: $wordPressInstaller->resetPermissions(); goto C162a; C86ad: $this->wordPressMultiSiteConfigValues["\x44\x4f\115\x41\x49\x4e\137\x43\x55\122\122\x45\x4e\x54\137\123\x49\124\105"]["\166\x61\x6c\165\145"] = $siteEntity->getDomainName(); goto E2684; F4702: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto b2074; Cee2b: $databaseUserName = $databaseUserEntity->getUserName(); goto F4702; e1fe2: $wordPressInstaller->downloadAndExtractLatestVersion(); goto c8d37; c8d37: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto C08fa; c8b85: $databaseHost = sprintf("\45\x73\x3a\x25\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto Cc733; b2074: $wordPressInstaller = new WordPressInstaller($siteEntity); goto e1fe2; C162a: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto a793d; a793d: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto Afb1d; A890b: $siteEntity->setDomainName($domainName); goto B3f1d; ce68e: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto b0eff; a3c1f: f4944: goto e2830; fc12e: return $siteEntity; goto Ccb0f; B3f1d: $siteEntity->setUser($siteUser); goto D5ae1; A6106: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto C9e48; fb5fb: $defaultVarnishCacheSettings = ["\x65\156\141\x62\x6c\145\144" => false, "\x73\145\162\x76\x65\x72" => self::VARNISH_CACHE_SERVER, "\x63\141\x63\150\145\x54\x61\x67\120\x72\145\146\x69\170" => substr(md5(time()), 0, 4)]; goto D62f8; e01bd: $phpSettingsEntity->setPhpVersion($phpVersion); goto B2a99; e526d: $certificateEntity->setCsr($csr); goto A6106; eaf04: $phpSiteCreator->createIndexPhp(); goto a0463; a2c1a: $constraintViolationList->addAll($phpSettingsConstraints); goto db85a; Cf675: $certificateEntity = $this->certificateEntityManager->createEntity(); goto fcfa6; be499: $siteEntity->setVhostTemplate($vhostTemplate); goto Aeb01; c74fc: $siteEntity = $this->siteEntityManager->createEntity(); goto C7d50; e6324: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto D04ae; Dea5a: $phpSite->setUser($siteEntity->getUser()); goto d3a66; ae490: $vhostTemplate->build(); goto A0db7; f126f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto c74fc; Db3ba: if (!(true === $varnishCache)) { goto Eedcf; } goto f2f1b; Ad0cb: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto D45b2; b0eff: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto eaf09; } goto e151d; Ef1d3: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto e526d; Bbf1a: if (!(false === empty($redirectionVhostTemplate))) { goto f4944; } goto e636a; b165c: if (!(true === is_null($subdomain) || "\167\x77\x77" == $subdomain)) { goto F8cac; } goto F3fef; D374e: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto ae803; F9fdf: if (!(true === is_null($subdomain))) { goto c17ec; } goto b46ef; f2e7e: $siteEntity->setCertificate($certificateEntity); goto Eea2f; Eea2f: $phpSite = new PhpSite(); goto Dea5a; D85d3: $this->siteEntityManager->updateEntity($siteEntity); goto fc12e; db85a: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e6324; F6a46: $subjectAlternativeNames = []; goto F9fdf; B1f29: $subdomain = false === empty($subdomain) ? $subdomain : null; goto f5169; ea466: $siteEntity->setRootDirectory($rootDirectory); goto D6adf; C39ca: c17ec: goto af237; Afb1d: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\x2f"); goto b2b70; Ae105: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F6a46; E3889: $phpSiteCreator->createPhpFpmPool(); goto dc168; C7d50: $siteEntity->setType(SiteEntity::TYPE_PHP); goto A890b; ae803: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto C92ce; d61dc: $siteEntity->setPhpSettings($phpSettingsEntity); goto e01bd; C9e48: $certificateEntity->setCertificate($selfSignedCertificate); goto f2e7e; D62f8: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto C6e2e; Cc24e: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\x2e\x2e\x2f\56\x2e\57\162\145\163\157\x75\x72\143\x65\x73\57\x6e\x67\151\x6e\x78\x2f\166\150\157\163\164\137\x74\145\x6d\x70\154\141\164\145\x2f\162\x65\144\x69\162\x65\143\x74\x2d\x68\x74\x74\x70\63"); goto a637a; ef161: $subjectAlternativeNames[] = $registrableDomain; goto aaade; De163: $phpSiteCreator->reloadNginxService(); goto Ba77d; c403a: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto E7efb; bc205: $phpSite->setPhpSettings($phpSettingsEntity); goto e2874; f5a6c: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto ae490; D04ae: eaf09: goto Cf675; b1516: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto bc2e9; bc2e9: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B1f29; f8181: $siteConstraints = $this->validator->validate($siteEntity); goto ce68e; f5169: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto f126f; Ee551: $phpSite->setCertificate($certificateEntity); goto bc205; A2441: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto B1db1; b3948: $phpSite->setDomainName($domainName); goto C5127; C92ce: $csr = $csrGenerator->generate(); goto A2441; D5ae1: $siteEntity->setUserPassword($siteUserPassword); goto ea466; C84e2: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto f5a6c; Aeb01: $phpSettingsEntity = new PhpSettingsEntity(); goto d61dc; D6adf: if (!(false === empty($varnishCache))) { goto ebe5e; } goto e618e; e2874: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto A79e6; A0db7: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Ba3b9; e2830: F8cac: goto be499; Ef817: $constraintViolationList->addAll($siteConstraints); goto a2c1a; C6e2e: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto c403a; F7650: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto C84e2; fb92e: $phpSiteCreator->createLogrotateFile(); goto eaf04; f7f6f: goto e3bf2; goto f085b; E6ba6: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto Ee551; B1db1: $certificateEntity->setDefaultCertificate(true); goto Ef1d3; Ba77d: $phpSiteCreator->resetPermissions(); goto Cfcb3; e618e: $siteEntity->setVarnishCache(true); goto Cd57f; Ba3b9: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto D85d3; f085b: e8de5: goto Cc24e; E87bc: $phpSiteCreator->createUser(); goto E6b0e; fcfa6: $certificateEntity->setSite($siteEntity); goto cc6cf; f2f1b: $phpSite->setVarnishCache(true); goto fb5fb; C5127: $phpSite->setRegistrableDomain($registrableDomain); goto Df588; Cfcb3: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Ad0cb; a0463: $phpSiteCreator->createPrivateKeyAndCertificate(); goto E3889; Cd57f: ebe5e: goto b165c; fcf9e: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\56\57\56\x2e\x2f\x72\145\163\x6f\x75\x72\x63\x65\x73\57\x6e\x67\x69\x6e\170\x2f\x76\x68\157\163\x74\137\164\x65\155\160\x6c\141\x74\145\57\162\145\x64\151\162\145\143\164"); goto f7f6f; D45b2: $vhostTemplate->resetProcessors(); goto F7650; F3fef: if (true === isset($_ENV["\x41\120\x50\137\x48\x54\x54\120\x33"]) && "\x74\162\x75\145" === $_ENV["\x41\x50\x50\x5f\110\x54\x54\120\x33"]) { goto e8de5; } goto fcf9e; a8ee7: $phpSiteCreator->createNginxVhost(); goto De163; A79e6: $phpSiteCreator = new PhpSiteCreator($phpSite); goto E87bc; B2a99: $phpSettingsEntity->setSite($siteEntity); goto f8181; e151d: $constraintViolationList = new ConstraintViolationList(); goto Ef817; cc6cf: $rsaKeyGenerator = new RsaKeyGenerator(); goto Ae105; C11a2: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Bbf1a; Df588: $phpSite->setSubdomain($subdomain); goto E6ba6; af237: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto a47b0; } goto ef161; dc168: $phpSiteCreator->reloadPhpFpmService(); goto Db3ba; d3a66: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto b3948; b46ef: $subjectAlternativeNames[] = sprintf("\167\167\x77\x2e\45\163", $domainName); goto C39ca; e636a: $vhostTemplate = sprintf("\x25\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto a3c1f; aaade: a47b0: goto D374e; E6b0e: $phpSiteCreator->createRootDirectory(); goto fb92e; E7efb: Eedcf: goto a8ee7; a637a: e3bf2: goto C11a2; b2b70: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b1516; Ccb0f: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto a1e5d; E45e8: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Dc768; F694c: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\56\56\57\x2e\x2e\x2f\162\145\163\157\x75\x72\143\x65\x73\57\156\147\151\x6e\170\x2f\x76\150\157\163\x74\x5f\164\x65\x6d\160\154\141\x74\x65\x2f\x72\145\144\x69\162\x65\143\164"); goto a5893; Cc4a2: $certificateEntity->setSite($siteEntity); goto ed368; b4b42: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto a9963; e0cca: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Edc16; A1775: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\x25\x73", $domainName); goto Dc22d; a655f: $siteEntity->setCertificate($certificateEntity); goto B4ad2; bbd10: $siteEntity->setVhostTemplate($vhostTemplate); goto Fb1bf; ce562: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto B658c; D7028: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto B6bb0; } goto F5216; A1405: throw new \Exception(implode("\73\x20", $errorMessages)); goto cceb7; Ad316: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto ba631; Deb2d: $nodejsSiteCreator->reloadNginxService(); goto Dab7e; b1f8f: $constraintViolationList->addAll($siteConstraints); goto ffffb; de781: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto Aa0fb; Ddc41: $nodejsSettingsEntity->setPort($port); goto Edb3a; af080: $siteConstraints = $this->validator->validate($siteEntity); goto B0ab5; f8e7e: $siteEntity = $this->siteEntityManager->createEntity(); goto bf918; Dae51: $nodejsSite->setCertificate($certificateEntity); goto Ff7fd; Cdedd: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Cc4a2; Fbcba: $nodejsSite->setDomainName($domainName); goto E4a49; f4144: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto F0884; f3675: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto a6ef1; F5216: $constraintViolationList = new ConstraintViolationList(); goto b1f8f; ba631: $this->siteEntityManager->updateEntity($siteEntity); goto D1f02; d73ba: $nodejsSiteCreator->createLogrotateFile(); goto d21f8; Dc768: $certificateEntity->setDefaultCertificate(true); goto A4575; f25fa: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto C0b17; D9930: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto a6cee; } goto faea6; C2126: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto Dae51; a5893: goto ea78d; goto bc814; a9963: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto f8e7e; e8614: $vhostTemplate->build(); goto d429f; a49e3: $certificateEntity->setCertificate($selfSignedCertificate); goto a655f; a66a2: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto A1405; A7bf1: Ba96a: goto f25fa; B0862: $csr = $csrGenerator->generate(); goto E45e8; Fb1bf: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto de781; cb7b1: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Fbcba; f99a7: $nodejsSiteCreator->createNginxVhost(); goto Deb2d; d21f8: $nodejsSiteCreator->createNvmDirectory(); goto fd1e2; B0ab5: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto D7028; Bd8a3: $nodejsSiteCreator->createUser(); goto f0704; A4575: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto f47ed; Dab7e: $nodejsSiteCreator->resetPermissions(); goto Da283; d429f: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Ad316; Bcf29: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto ae2f0; eeb61: $subdomain = $resolvedDomainName->subDomain()->toString(); goto d5c35; Dc22d: Bcbe5: goto D6f80; bc814: ff9a8: goto aef84; bf918: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto c4941; E4a49: $nodejsSite->setRegistrableDomain($registrableDomain); goto d2415; C09ab: $nodejsSite->setUser($siteEntity->getUser()); goto cb7b1; f0704: $nodejsSiteCreator->createRootDirectory(); goto d73ba; eb0f1: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto eeb61; B658c: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e8614; Edc16: if (!(false === empty($redirectionVhostTemplate))) { goto a1bc6; } goto f3675; B4ad2: $nodejsSite = new NodejsSite(); goto C09ab; faea6: if (true === isset($_ENV["\101\120\120\x5f\110\124\x54\x50\63"]) && "\164\x72\x75\145" === $_ENV["\101\x50\120\x5f\x48\x54\124\x50\63"]) { goto ff9a8; } goto F694c; d2415: $nodejsSite->setSubdomain($subdomain); goto C2126; B3169: $siteEntity->setRootDirectory($domainName); goto D9930; ffffb: $constraintViolationList->addAll($nodejsSettingsConstraints); goto a66a2; D6f80: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto Ba96a; } goto E8a04; fd1e2: $nodejsSiteCreator->installNodejs(); goto c2ee1; a1e5d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto eb0f1; F2102: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Fd4d2; D3a79: if (!(true === is_null($subdomain))) { goto Bcbe5; } goto A1775; cceb7: B6bb0: goto Cdedd; Da283: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto F2102; Edb3a: $nodejsSettingsEntity->setSite($siteEntity); goto af080; ebfbf: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ce562; E8a04: $subjectAlternativeNames[] = $registrableDomain; goto A7bf1; Bc6f3: a6cee: goto bbd10; d5c35: $subdomain = false === empty($subdomain) ? $subdomain : null; goto b4b42; C0b17: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto B0862; ed368: $rsaKeyGenerator = new RsaKeyGenerator(); goto Bcf29; aef84: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\x2e\56\x2f\56\x2e\57\162\145\x73\x6f\x75\x72\143\145\163\57\x6e\x67\151\x6e\170\x2f\x76\x68\x6f\163\x74\137\164\x65\x6d\x70\x6c\141\x74\x65\57\162\145\144\151\x72\145\143\x74\55\150\164\x74\160\x33"); goto eb5fd; F0884: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto Bd8a3; D1f02: return $siteEntity; goto Acc1b; E9dfe: $siteEntity->setUser($siteUser); goto Bd782; c4941: $siteEntity->setDomainName($domainName); goto E9dfe; Ff7fd: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto f4144; Aa0fb: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto Ddc41; f47ed: $certificateEntity->setCsr($csr); goto E60d9; Fd4d2: $vhostTemplate->resetProcessors(); goto ebfbf; a6ef1: a1bc6: goto Bc6f3; E60d9: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto a49e3; Bd782: $siteEntity->setUserPassword($siteUserPassword); goto B3169; ae2f0: $subjectAlternativeNames = []; goto D3a79; c2ee1: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto f99a7; eb5fd: ea78d: goto e0cca; Acc1b: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto efd96; D85d6: $siteEntity->setUserPassword($siteUserPassword); goto Ffab3; f5468: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto E7bf9; E04f0: $subdomain = false === empty($subdomain) ? $subdomain : null; goto a32e6; F39d2: $vhostTemplate = sprintf("\x25\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto Ff307; d74ee: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto E156e; Be135: $certificateEntity->setSite($siteEntity); goto c35cd; Dcdc5: $constraintViolationList = new ConstraintViolationList(); goto Db6fd; F6f6c: if (!(false === empty($redirectionVhostTemplate))) { goto C2b4f; } goto F39d2; b839f: $vhostTemplate->build(); goto D142a; b205a: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\56\x2e\57\56\x2e\57\162\x65\x73\x6f\165\162\143\145\x73\x2f\156\147\x69\x6e\170\x2f\x76\x68\x6f\163\x74\x5f\164\x65\155\x70\154\x61\x74\145\57\x72\x65\x64\x69\x72\x65\143\x74"); goto c4a84; A9c95: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto b40da; E1c61: E1fb2: goto ebd7f; B8a7c: $pythonSiteCreator->createRootDirectory(); goto d0f1c; ac31c: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto C2251; A04ce: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto a0ac8; } goto Ae455; D94f6: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto c1ea6; ff5c7: Bcfaa: goto fa57b; A3982: $pythonSite->setPythonSettings($pythonSettingsEntity); goto Ca106; a32e6: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto d06e6; cb0af: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto F1144; fa57b: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto f260e; } goto ff91c; b62d6: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto A8e33; bd375: $pythonSiteCreator->reloadNginxService(); goto C42c4; Ebb7e: C79c8: goto a4336; D142a: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto e46d8; Ca106: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto a173a; A3dfe: a0ac8: goto e7287; Db6fd: $constraintViolationList->addAll($siteConstraints); goto A7ca7; B2705: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto dfce2; ff91c: $subjectAlternativeNames[] = $registrableDomain; goto dd279; Fd3fc: a5e83: goto Cd90c; B2970: $pythonSite = new PythonSite(); goto Dcc2d; Ffab3: $siteEntity->setRootDirectory($domainName); goto A04ce; d0f1c: $pythonSiteCreator->createLogrotateFile(); goto C71f2; efd96: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto d74ee; B16f6: if (!(true === is_null($subdomain))) { goto Bcfaa; } goto f13ae; Cd90c: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Be135; D7238: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto ade5a; b40da: $certificateEntity->setDefaultCertificate(true); goto b62d6; c4a84: goto C79c8; goto E1c61; A8e33: $certificateEntity->setCsr($csr); goto f64ba; acc85: $pythonSite->setCertificate($certificateEntity); goto A3982; a23a9: $pythonSite->setRegistrableDomain($registrableDomain); goto dbb88; Dcc2d: $pythonSite->setUser($siteEntity->getUser()); goto ac31c; B36b0: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto B5c0a; dfce2: $pythonSiteCreator->createNginxVhost(); goto bd375; F662e: $siteEntity->setDomainName($domainName); goto Ea193; Eb15d: $siteEntity = $this->siteEntityManager->createEntity(); goto E6530; dbb88: $pythonSite->setSubdomain($subdomain); goto B31d7; ade5a: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto a5e83; } goto Dcdc5; E6530: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto F662e; B6d3d: $pythonSettingsEntity = new PythonSettingsEntity(); goto D60d0; bab32: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto b839f; Ff307: C2b4f: goto A3dfe; B5c0a: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto B657c; d06e6: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Eb15d; ebbbc: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto C75f8; ccf86: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E483a; a4336: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto F6f6c; C71f2: $pythonSiteCreator->writePythonVersionFile(); goto B2705; c1ea6: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto bab32; e7287: $siteEntity->setVhostTemplate($vhostTemplate); goto B6d3d; F1144: $pythonSettingsEntity->setPort($port); goto E5914; d80f9: $siteConstraints = $this->validator->validate($siteEntity); goto D7238; b49c4: $subjectAlternativeNames = []; goto B16f6; Ea193: $siteEntity->setUser($siteUser); goto D85d6; d1c8c: $siteEntity->setCertificate($certificateEntity); goto B2970; B31d7: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto acc85; c35cd: $rsaKeyGenerator = new RsaKeyGenerator(); goto d9cc5; A7ca7: $constraintViolationList->addAll($pythonSettingsConstraints); goto f5468; f13ae: $subjectAlternativeNames[] = sprintf("\x77\167\167\x2e\x25\x73", $domainName); goto ff5c7; Ae455: if (true === isset($_ENV["\101\x50\x50\137\110\x54\124\120\x33"]) && "\x74\162\165\145" === $_ENV["\x41\120\120\x5f\x48\x54\x54\120\63"]) { goto E1fb2; } goto b205a; C42c4: $pythonSiteCreator->resetPermissions(); goto B36b0; c146f: $pythonSiteCreator->createUser(); goto B8a7c; e46d8: $this->siteEntityManager->updateEntity($siteEntity); goto ccf86; E156e: $subdomain = $resolvedDomainName->subDomain()->toString(); goto E04f0; ebd7f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\56\56\x2f\56\56\x2f\x72\x65\163\x6f\165\x72\x63\145\163\x2f\x6e\x67\x69\x6e\x78\x2f\x76\150\157\x73\x74\137\x74\145\155\160\x6c\141\164\x65\57\162\145\x64\151\162\x65\x63\164\x2d\x68\x74\164\x70\x33"); goto Ebb7e; aacaa: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto ebbbc; B657c: $vhostTemplate->resetProcessors(); goto D94f6; E483a: return $siteEntity; goto B5ff9; d9cc5: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto b49c4; dd279: f260e: goto aacaa; a173a: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto c146f; E7bf9: throw new \Exception(implode("\x3b\40", $errorMessages)); goto Fd3fc; C75f8: $csr = $csrGenerator->generate(); goto A9c95; D60d0: $siteEntity->setPythonSettings($pythonSettingsEntity); goto cb0af; f64ba: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto E4ecd; E5914: $pythonSettingsEntity->setSite($siteEntity); goto d80f9; E4ecd: $certificateEntity->setCertificate($selfSignedCertificate); goto d1c8c; C2251: $pythonSite->setDomainName($domainName); goto a23a9; B5ff9: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto C83c5; Dfc69: $rsaKeyGenerator = new RsaKeyGenerator(); goto Af91d; f0eb7: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Da4be; E3602: $subjectAlternativeNames[] = $registrableDomain; goto B4d69; B4ebd: $certificateEntity->setCsr($csr); goto E04fa; F58ea: if (true === isset($_ENV["\x41\x50\x50\x5f\x48\124\124\120\63"]) && "\164\162\x75\145" === $_ENV["\101\x50\x50\x5f\110\124\124\120\63"]) { goto A33a6; } goto F32dc; a341a: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto b568c; Fbb6d: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto de95a; bd8ae: if (!(true === is_null($subdomain) || "\167\x77\x77" == $subdomain)) { goto Aa7c0; } goto F58ea; Cd74b: $siteConstraints = $this->validator->validate($siteEntity); goto ed23e; d87e1: $staticSiteCreator->resetPermissions(); goto f446b; E6564: if (!(true === is_null($subdomain))) { goto d0ce2; } goto a5526; f037a: $certificateEntity->setCertificate($selfSignedCertificate); goto D24d1; C83c5: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto c733b; c733b: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto dd337; E04fa: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto f037a; b568c: $siteEntity->setDomainName($domainName); goto d5181; f446b: $vhostTemplate = new StaticVhostTemplate($staticSite); goto a166a; f80d9: $staticSiteCreator->createPrivateKeyAndCertificate(); goto F2056; ba38b: $staticSite->setDomainName($domainName); goto ca2a5; e11b9: $staticSiteCreator->createRootDirectory(); goto F54fc; De561: d0ce2: goto e823c; e823c: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto C804a; } goto E3602; aa274: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto ba38b; ca2a5: $staticSite->setRegistrableDomain($registrableDomain); goto bac8b; be756: $vhostTemplate->resetProcessors(); goto Aca37; d5088: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\56\56\x2f\56\x2e\x2f\x72\145\163\157\x75\x72\143\x65\x73\x2f\156\x67\151\156\170\57\166\x68\x6f\163\x74\137\x74\x65\x6d\x70\154\141\164\145\x2f\x72\145\x64\151\x72\145\143\x74\55\150\x74\164\160\x33"); goto A7656; a84fc: $vhostTemplate->build(); goto D8377; a970b: $certificateEntity->setDefaultCertificate(true); goto ab440; cec9a: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto a970b; Edcd1: $staticSiteCreator = new StaticSiteCreator($staticSite); goto D9b66; e4431: throw new \Exception(implode("\73\x20", $errorMessages)); goto d5fe9; A56b9: A33a6: goto d5088; F0b02: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Edcd1; dd337: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c82e8; a2784: $staticSiteCreator->createIndexHtml(); goto f80d9; d5fe9: b2e4d: goto ef79d; D9b66: $staticSiteCreator->createUser(); goto e11b9; F32dc: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\57\x2e\x2e\57\x2e\x2e\57\162\145\x73\x6f\165\162\143\145\163\57\x6e\147\151\x6e\x78\57\166\150\157\163\164\x5f\x74\x65\155\x70\154\x61\x74\145\x2f\162\x65\144\151\162\145\x63\164"); goto ba19b; B67c0: Aa7c0: goto B4a1a; Da498: return $siteEntity; goto F5ff4; be013: $staticSiteCreator->reloadNginxService(); goto d87e1; de090: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto ca1d3; D24d1: $siteEntity->setCertificate($certificateEntity); goto Bb23a; a9fea: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e995a; B3705: $constraintViolationList = new ConstraintViolationList(); goto A4013; A4013: $constraintViolationList->addAll($siteConstraints); goto de6d7; D42c8: $siteEntity = $this->siteEntityManager->createEntity(); goto a341a; Abe56: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto a9fea; B4d69: C804a: goto Abe56; e3095: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto B22ef; Aca37: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto f0eb7; ed23e: if (!count($siteConstraints)) { goto b2e4d; } goto B3705; A7656: Fedbc: goto Fbb6d; acb3a: $siteEntity->setUserPassword($siteUserPassword); goto f6f5a; F54fc: $staticSiteCreator->createLogrotateFile(); goto a2784; f6f5a: $siteEntity->setRootDirectory($domainName); goto bd8ae; F2056: $staticSiteCreator->createNginxVhost(); goto be013; a166a: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto be756; ba19b: goto Fedbc; goto A56b9; e995a: $csr = $csrGenerator->generate(); goto cec9a; f2157: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D42c8; D4639: $staticSite->setUser($siteEntity->getUser()); goto aa274; B22ef: $this->siteEntityManager->updateEntity($siteEntity); goto Da498; D8377: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto e3095; A6b57: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto f2157; bac8b: $staticSite->setSubdomain($subdomain); goto de090; ab440: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B4ebd; de95a: if (!(false === empty($redirectionVhostTemplate))) { goto A2ab1; } goto E41e5; a5526: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\x25\x73", $domainName); goto De561; D3c68: A2ab1: goto B67c0; Caa18: $certificateEntity->setSite($siteEntity); goto Dfc69; e3cc4: $subjectAlternativeNames = []; goto E6564; Da4be: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a84fc; d5181: $siteEntity->setUser($siteUser); goto acb3a; Af91d: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto e3cc4; de6d7: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e4431; ef79d: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Caa18; Bb23a: $staticSite = new StaticSite(); goto D4639; c82e8: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A6b57; E41e5: $vhostTemplate = sprintf("\x25\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto D3c68; B4a1a: $siteEntity->setVhostTemplate($vhostTemplate); goto Cd74b; ca1d3: $staticSite->setCertificate($certificateEntity); goto F0b02; F5ff4: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto f946f; e6556: $vhostTemplate = sprintf("\45\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto e854c; bd65b: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto d5c4c; da15b: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto Ceef3; dbcd7: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto C6444; Aea47: throw new \Exception(implode("\73\40", $errorMessages)); goto C91c6; C91c6: Ac279: goto Cdc93; f4a18: $reversProxySiteCreator->createRootDirectory(); goto A14be; C3af3: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Aea47; E4831: $reversProxySiteCreator->resetPermissions(); goto ab46f; d487c: $siteConstraints = $this->validator->validate($siteEntity); goto E6e5c; F9034: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto a37cc; e56de: $siteEntity->setRootDirectory($domainName); goto bd65b; a37cc: $reversProxySiteCreator->createUser(); goto f4a18; c70da: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto aa1f3; ca763: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto f2f96; Ae2b6: if (!(true === is_null($subdomain))) { goto b7923; } goto C5b55; f9e1d: if (true === isset($_ENV["\101\120\x50\137\110\x54\x54\120\x33"]) && "\x74\x72\x75\x65" === $_ENV["\101\120\120\x5f\110\124\x54\120\63"]) { goto bee4f; } goto e4cf7; Bba5b: C32b9: goto e36eb; Bb309: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto Afa95; } goto a1910; e0326: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c7fc0; f1908: $constraintViolationList->addAll($siteConstraints); goto C3af3; d3b61: b7923: goto Bb309; C331d: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto B5f9d; eb556: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c9df9; c4475: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto a6f24; Ffe38: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\x2e\56\57\56\x2e\x2f\162\145\x73\x6f\165\162\x63\145\x73\57\x6e\x67\x69\x6e\x78\x2f\x76\x68\x6f\163\x74\137\164\145\x6d\x70\x6c\x61\164\145\x2f\162\145\144\151\x72\x65\143\x74\x2d\x68\164\x74\x70\63"); goto Bba5b; D6943: $reversProxySiteCreator->reloadNginxService(); goto E4831; F9d58: $siteEntity->setUserPassword($siteUserPassword); goto e56de; D954e: $certificateEntity->setCsr($csr); goto C331d; aed2f: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e55dd; b704b: $siteEntity->setUser($siteUser); goto F9d58; d6147: $reverseProxySite->setRegistrableDomain($registrableDomain); goto Bcf0e; a6f24: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto D5fb6; Fab8b: $constraintViolationList = new ConstraintViolationList(); goto f1908; B97c3: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto F8623; C5b55: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\56\45\x73", $domainName); goto d3b61; aa1f3: $vhostTemplate->resetProcessors(); goto aed2f; e55dd: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto B97c3; Cdc93: $certificateEntity = $this->certificateEntityManager->createEntity(); goto dba12; Ccd70: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Ee526; ad772: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto E6183; f946f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto aba49; c7fc0: $certificateEntity->setDefaultCertificate(true); goto F1c5b; Aaca7: $rsaKeyGenerator = new RsaKeyGenerator(); goto ad772; F8623: $vhostTemplate->build(); goto c4475; E6e5c: if (!count($siteConstraints)) { goto Ac279; } goto Fab8b; B5f9d: $certificateEntity->setCertificate($selfSignedCertificate); goto c8dcb; e36eb: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto e4a0f; Fd491: $reverseProxySite = new ReverseProxySite(); goto a156f; e4a0f: if (!(false === empty($redirectionVhostTemplate))) { goto C63cc; } goto e6556; Ceef3: $siteEntity->setDomainName($domainName); goto b704b; fd430: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto Cb32e; C6444: $siteEntity = $this->siteEntityManager->createEntity(); goto da15b; Aff45: Afa95: goto ca763; dba12: $certificateEntity->setSite($siteEntity); goto Aaca7; ab43c: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto f4d05; d5c4c: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto D5b6e; } goto f9e1d; e854c: C63cc: goto be2d9; Bcf0e: $reverseProxySite->setSubdomain($subdomain); goto fd430; a1910: $subjectAlternativeNames[] = $registrableDomain; goto Aff45; A14be: $reversProxySiteCreator->createLogrotateFile(); goto Ccd70; F1c5b: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto D954e; ab46f: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto c70da; be2d9: D5b6e: goto C0530; Cb32e: $reverseProxySite->setCertificate($certificateEntity); goto ab43c; Ee526: $reversProxySiteCreator->createNginxVhost(); goto D6943; afe82: $csr = $csrGenerator->generate(); goto e0326; e4cf7: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\x2e\56\x2f\x2e\56\x2f\162\145\163\x6f\x75\x72\143\x65\163\x2f\x6e\147\x69\156\x78\57\x76\150\157\163\164\137\164\145\x6d\160\154\141\164\145\57\x72\145\144\x69\x72\x65\143\x74"); goto Fa7e2; e8458: return $siteEntity; goto b3d80; aba49: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto eb556; E7eaf: bee4f: goto Ffe38; E6183: $subjectAlternativeNames = []; goto Ae2b6; f2f96: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto afe82; a156f: $reverseProxySite->setUser($siteEntity->getUser()); goto c07e4; f4d05: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto F9034; Fa7e2: goto C32b9; goto E7eaf; E60ca: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto dbcd7; c94aa: $reverseProxySite->setDomainName($domainName); goto d6147; c8dcb: $siteEntity->setCertificate($certificateEntity); goto Fd491; C0530: $siteEntity->setVhostTemplate($vhostTemplate); goto d487c; D5fb6: $this->siteEntityManager->updateEntity($siteEntity); goto e8458; c07e4: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto c94aa; c9df9: $subdomain = false === empty($subdomain) ? $subdomain : null; goto E60ca; b3d80: } public function installedWordPressSite(Request $request) : Response { goto D65b0; f5a06: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto Cf9f3; A0819: if (false === empty($siteCredentials)) { goto E8e12; } goto c0cdd; dc4e0: E8e12: goto f5a06; A06cf: eba23: goto c1f7a; Cf9f3: $response = $this->render("\106\162\157\156\x74\145\x6e\144\x2f\123\x69\x74\145\x2f\116\145\167\57\167\157\x72\x64\160\162\145\x73\x73\55\151\156\163\x74\141\x6c\154\145\144\x2e\150\164\155\154\56\164\x77\151\x67", ["\163\x69\164\145\103\162\145\x64\x65\156\164\x69\x61\154\163" => $siteCredentials]); goto B5e6b; eee83: goto eba23; goto dc4e0; c1f7a: return $response; goto e8e7a; c0cdd: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\151\x74\x65\163")); goto eee83; D65b0: $session = $request->getSession(); goto B8d60; B5e6b: return $response; goto A06cf; B8d60: $siteCredentials = $session->get("\x73\151\x74\x65\103\162\x65\x64\x65\x6e\164\151\141\x6c\x73"); goto A0819; e8e7a: } private function renderSiteCredentials(array $siteCredentials) : string { goto B5e64; fe65b: foreach ($siteCredentials as $section => $sectionData) { goto c6958; a2c28: $renderedCredentials .= PHP_EOL; goto C74e4; b1881: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\45\x73\72\40\45\163", $key, $value) . PHP_EOL; E37d4: } goto c4e4f; c4e4f: de74a: goto a2c28; c6958: $renderedCredentials .= $section . PHP_EOL; goto Bcf1e; Bcf1e: $renderedCredentials .= "\55\55\55\x2d\55\55\x2d\55\x2d\55\55\55\55\x2d\x2d\55\55\x2d\x2d\55\x2d\55\x2d\55\x2d\x2d\55\x2d\55\x2d\55\55\55\55\55\x2d\55\55\x2d\55\55\55\x2d\x2d\x2d\55\55\55\55\55\55\x2d\55\55" . PHP_EOL; goto b1881; C74e4: Db6ba: goto b4770; b4770: } goto Eaf7f; B5e64: $renderedCredentials = ''; goto fe65b; Cb65e: return $renderedCredentials; goto b3788; Eaf7f: D8b0e: goto Cb65e; b3788: } private function getVhostTemplateEntity(string $name) : mixed { goto B8759; B8759: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto d1734; A314a: aebe3: goto A9e91; d1734: if (!(true === is_null($vhostTemplateEntity))) { goto aebe3; } goto e3d11; A9e91: return $vhostTemplateEntity; goto b2277; e3d11: throw new \Exception($this->translator->trans("\126\x68\x6f\163\164\x20\124\145\x6d\x70\x6c\141\164\145\x20\x25\166\x68\x6f\163\x74\x54\x65\x6d\160\154\141\164\x65\x25\x20\x64\x6f\145\163\x20\156\x6f\164\x20\x65\x78\151\163\164\56", ["\45\x76\x68\x6f\163\164\x54\x65\155\x70\154\141\x74\x65\45" => $name])); goto A314a; b2277: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto Bd2f4; Bd2f4: $errorMessages = []; goto B4840; B4840: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\72\x20\x25\x73", $constraint->getPropertyPath(), $constraint->getMessage()); Bff11: } goto Eb58b; Eb58b: bbb03: goto Ab5e4; Ab5e4: return $errorMessages; goto d1ebc; d1ebc: } private function generateNameFromDomainName(string $domainName) : string { goto Ab8e0; c754f: $name = $explodedRegistrableDomain[0] ?? ''; goto Ae7f8; Ae7f8: E3339: goto f0f5c; c2045: if (!(false === empty($subdomain))) { goto e83d5; } goto d72b8; eb103: $name = sprintf("\x25\x73\x2d\x25\x73", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto A948e; A948e: e83d5: goto E8d6b; E8d6b: goto E3339; goto A8e5d; A8e5d: B2fe4: goto c754f; a6354: $subdomain = $resolvedDomainName->subDomain()->toString(); goto df53f; f0f5c: return $name; goto C178e; df53f: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto A4f55; da91d: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a6354; d72b8: $explodedSubdomain = explode("\x2e", $subdomain); goto eb103; b30ff: $name = $explodedRegistrableDomain[0] ?? ''; goto c2045; Ab8e0: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto da91d; A4f55: if ("\x77\x77\x77" == $subdomain) { goto B2fe4; } goto b30ff; C178e: } private function getUniqueDatabaseName(string $databaseName) : string { goto Ea0f0; E4ca6: $databaseExists = in_array($uniqueDatabaseName, $databases); goto B346a; Db1f7: C546d: goto e1d17; A28ad: return $uniqueDatabaseName; goto E27c1; F53d3: fe484: goto E4ca6; d813c: if (!(0 < $i)) { goto fe484; } goto E6936; cc4b9: F622e: goto d813c; Ea0f0: $uniqueDatabaseName = $databaseName; goto Ca81e; c0859: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto dec68; ebc41: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto c0859; b8069: $uniqueDatabaseName = sprintf("\x25\163\x2d\x64\x62", $uniqueDatabaseName); goto Db1f7; Ca81e: if (!(strlen($uniqueDatabaseName) <= 3)) { goto C546d; } goto b8069; dec68: $databases = $databaseConnection->getDatabases(); goto cc4b9; E6936: $uniqueDatabaseName = sprintf("\45\x73\55\45\163", $databaseName, $i); goto F53d3; e0200: if (true === $databaseExists) { goto F622e; } goto d589a; B346a: $i++; goto e0200; e1d17: $i = 0; goto ebc41; d589a: D4623: goto A28ad; E27c1: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto Ebe1f; A0e3a: e89e0: goto f89f0; beff1: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto e89e0; } goto a6935; f89f0: $i = 0; goto E3b89; e0c10: if (!(0 < $i)) { goto f0a91; } goto Ae934; b90b5: f0a91: goto Ad989; Ff4a4: E3504: goto f72fb; Ad989: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto Cc671; Ebe1f: $uniqueDatabaseUserName = $databaseUserName; goto beff1; Ae934: $uniqueDatabaseUserName = sprintf("\45\x73\x2d\45\x73", $databaseUserName, $i); goto b90b5; C6ec1: return $uniqueDatabaseUserName; goto fefac; Cc671: $i++; goto Cdd51; Cdd51: if (false === is_null($databaseUserEntity)) { goto ba9f7; } goto Ff4a4; f72fb: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto C6ec1; E3b89: ba9f7: goto e0c10; a6935: $uniqueDatabaseUserName = sprintf("\x25\163\x2d\144\x62", $uniqueDatabaseUserName); goto A0e3a; fefac: } private function hasPermissions() : bool { goto Ec920; B8e71: return true; goto F2fee; Ec920: $user = $this->getUser(); goto B3ce4; F2fee: b9a41: goto f1993; B3ce4: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto b9a41; } goto B8e71; f1993: return false; goto B76e9; B76e9: } }
